@@ -34,8 +34,11 @@ newtype InterpreterT m a = InterpreterT {
                            }
     deriving (Functor, Monad, MonadIO, MonadThrow, MonadCatch, MonadMask)
 
-execute :: (MonadIO m, MonadMask m, Functor m)
-        => String
+execute :: (MonadIO m, MonadMask m
+#if __GLASGOW_HASKELL__ < 800
+            , Functor m
+#endif
+        ) => String
         -> InterpreterSession
         -> InterpreterT m a
         -> m (Either InterpreterError a)
@@ -47,7 +50,11 @@ execute libdir s = try
 instance MonadTrans InterpreterT where
     lift = InterpreterT . lift . lift
 
-runGhcImpl :: (MonadIO m, MonadThrow m, MonadMask m, Functor m) => RunGhc (InterpreterT m) a
+runGhcImpl :: (MonadIO m, MonadMask m
+#if __GLASGOW_HASKELL__ < 800
+               , MonadThrow m, Functor m
+#endif
+               ) => RunGhc (InterpreterT m) a
 runGhcImpl a =
   InterpreterT (lift a)
    `catches`
@@ -107,22 +114,31 @@ initialize args =
 -- NB. The underlying ghc will overwrite certain signal handlers
 -- (SIGINT, SIGHUP, SIGTERM, SIGQUIT on Posix systems, Ctrl-C handler on Windows).
 -- In future versions of hint, this might be controlled by the user.
-runInterpreter :: (MonadIO m, MonadMask m, Functor m)
-               => InterpreterT m a
+runInterpreter :: (MonadIO m, MonadMask m
+#if __GLASGOW_HASKELL__ < 800
+                   , Functor m
+#endif
+               ) => InterpreterT m a
                -> m (Either InterpreterError a)
 runInterpreter = runInterpreterWithArgs []
 
 -- | Executes the interpreter, setting args passed in as though they
 -- were command-line args. Returns @Left InterpreterError@ in case of
 -- error.
-runInterpreterWithArgs :: (MonadIO m, MonadMask m, Functor m)
-                       => [String]
+runInterpreterWithArgs :: (MonadIO m, MonadMask m
+#if __GLASGOW_HASKELL__ < 800
+                           , Functor m
+#endif
+                       ) => [String]
                        -> InterpreterT m a
                        -> m (Either InterpreterError a)
 runInterpreterWithArgs args = runInterpreterWithArgsLibdir args GHC.Paths.libdir
 
-runInterpreterWithArgsLibdir :: (MonadIO m, MonadMask m, Functor m)
-                             => [String]
+runInterpreterWithArgsLibdir :: (MonadIO m, MonadMask m
+#if __GLASGOW_HASKELL__ < 800
+                                 , Functor m
+#endif
+                             ) => [String]
                              -> String
                              -> InterpreterT m a
                              -> m (Either InterpreterError a)
@@ -134,8 +150,10 @@ runInterpreterWithArgsLibdir args libdir action =
           newInterpreterSession = newSessionData ()
           cleanSession =
                do cleanPhantomModules
+#if __GLASGOW_HASKELL__ < 800
                   runGhc $ do dflags <- GHC.getSessionDynFlags
                               GHC.defaultCleanupHandler dflags (return ())
+#endif
 
 {-# NOINLINE uniqueToken #-}
 uniqueToken :: MVar ()
@@ -182,7 +200,11 @@ newSessionData a =
        }
 
 mkLogHandler :: IORef [GhcError] -> GhcErrLogger
+#if __GLASGOW_HASKELL__ >= 800
+mkLogHandler r df _ _ src style msg =
+#else
 mkLogHandler r df _ src style msg =
+#endif
     let renderErrMsg = GHC.showSDoc df
         errorEntry = mkGhcError renderErrMsg src style msg
     in modifyIORef r (errorEntry :)
@@ -203,6 +225,10 @@ instance (MonadIO m, MonadMask m, Functor m) => MonadInterpreter (InterpreterT m
     --
     runGhc = runGhcImpl
 
+#if __GLASGOW_HASKELL__ >= 800
+instance (Monad m) => Applicative (InterpreterT m) where
+#else
 instance (Monad m, Applicative m) => Applicative (InterpreterT m) where
+#endif
     pure  = return
     (<*>) = ap
